@@ -52,7 +52,8 @@ find_files(void)
 	return true;
 }
 
-FILE *open_score_file(char *mode)
+FILE *
+open_score_file(char *mode)
 {
 	return fopen("scores", mode);
 }
@@ -91,10 +92,22 @@ static bool
 is_dir(char *dirname)
 {
 	struct stat buf;
-	stat(dirname, &buf);
+	if(stat(dirname, &buf)) {
+		return false;
+	}
 	return S_ISDIR(buf.st_mode);
 }
 
+static bool
+is_file(char *filename)
+{
+	struct stat buf;
+	if(stat(filename, &buf)) {
+		return false;
+	}
+	return S_ISREG(buf.st_mode);
+}
+
 static bool
 find_data_dir(void)
 {
@@ -108,7 +121,11 @@ find_data_dir(void)
 	for(i=0; i<3; i++) {
 		if(!data_options[i]) continue;
 		g_data_dir = strdup(data_options[i]);
-		if(is_dir(g_data_dir)) return true;
+		if(is_dir(g_data_dir)) {
+			char *s = add_path(g_data_dir, "b_variations.png");
+			if(s) if(is_file(s))
+				return true;
+		}
 	}
 
 	fprintf(stderr, "Can't find VoR data! Tried:\n");
